@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,15 +33,17 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.redis_v1beta1.services.cloud_redis import pagers
-from google.cloud.redis_v1beta1.types import cloud_redis
 from google.protobuf import any_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import CloudRedisTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import CloudRedisGrpcAsyncIOTransport
+
+from google.cloud.redis_v1beta1.services.cloud_redis import pagers
+from google.cloud.redis_v1beta1.types import cloud_redis
+
 from .client import CloudRedisClient
+from .transports.base import DEFAULT_CLIENT_INFO, CloudRedisTransport
+from .transports.grpc_asyncio import CloudRedisGrpcAsyncIOTransport
 
 
 class CloudRedisAsyncClient:
@@ -243,14 +245,13 @@ class CloudRedisAsyncClient:
         regions available to the project are queried, and the results
         are aggregated.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1beta1
 
-            def sample_list_instances():
+            async def sample_list_instances():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1beta1.ListInstancesRequest(
@@ -261,7 +262,7 @@ class CloudRedisAsyncClient:
                 page_result = client.list_instances(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -324,12 +325,20 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListInstancesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -350,9 +359,9 @@ class CloudRedisAsyncClient:
 
             from google.cloud import redis_v1beta1
 
-            def sample_get_instance():
+            async def sample_get_instance():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1beta1.GetInstanceRequest(
@@ -360,7 +369,7 @@ class CloudRedisAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_instance(request=request)
+                response = await client.get_instance(request=request)
 
                 # Handle the response
                 print(response)
@@ -419,7 +428,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -438,14 +452,13 @@ class CloudRedisAsyncClient:
         This information is not included in the details returned
         to GetInstance.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1beta1
 
-            def sample_get_instance_auth_string():
+            async def sample_get_instance_auth_string():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1beta1.GetInstanceAuthStringRequest(
@@ -453,7 +466,7 @@ class CloudRedisAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_instance_auth_string(request=request)
+                response = await client.get_instance_auth_string(request=request)
 
                 # Handle the response
                 print(response)
@@ -512,7 +525,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -543,14 +561,13 @@ class CloudRedisAsyncClient:
         The returned operation is automatically deleted after a few
         hours, so there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1beta1
 
-            def sample_create_instance():
+            async def sample_create_instance():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 instance = redis_v1beta1.Instance()
@@ -569,7 +586,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -657,7 +674,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -687,14 +709,13 @@ class CloudRedisAsyncClient:
         operation is automatically deleted after a few hours, so
         there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1beta1
 
-            def sample_update_instance():
+            async def sample_update_instance():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 instance = redis_v1beta1.Instance()
@@ -711,7 +732,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -793,7 +814,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -819,14 +845,13 @@ class CloudRedisAsyncClient:
         r"""Upgrades Redis instance to the newer Redis version
         specified in the request.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1beta1
 
-            def sample_upgrade_instance():
+            async def sample_upgrade_instance():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1beta1.UpgradeInstanceRequest(
@@ -839,7 +864,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -912,7 +937,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -945,14 +975,13 @@ class CloudRedisAsyncClient:
         The returned operation is automatically deleted after a
         few hours, so there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1beta1
 
-            def sample_import_instance():
+            async def sample_import_instance():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 input_config = redis_v1beta1.InputConfig()
@@ -968,7 +997,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1041,7 +1070,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1070,14 +1104,13 @@ class CloudRedisAsyncClient:
         The returned operation is automatically deleted after a
         few hours, so there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1beta1
 
-            def sample_export_instance():
+            async def sample_export_instance():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 output_config = redis_v1beta1.OutputConfig()
@@ -1093,7 +1126,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1166,7 +1199,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1193,14 +1231,13 @@ class CloudRedisAsyncClient:
         replica node for a specific STANDARD tier Cloud
         Memorystore for Redis instance.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1beta1
 
-            def sample_failover_instance():
+            async def sample_failover_instance():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1beta1.FailoverInstanceRequest(
@@ -1212,7 +1249,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1286,7 +1323,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1311,14 +1353,13 @@ class CloudRedisAsyncClient:
         r"""Deletes a specific Redis instance.  Instance stops
         serving and data is deleted.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1beta1
 
-            def sample_delete_instance():
+            async def sample_delete_instance():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1beta1.DeleteInstanceRequest(
@@ -1330,7 +1371,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1404,7 +1445,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1431,14 +1477,13 @@ class CloudRedisAsyncClient:
         r"""Reschedule maintenance for a given instance in a
         given project and location.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1beta1
 
-            def sample_reschedule_maintenance():
+            async def sample_reschedule_maintenance():
                 # Create a client
-                client = redis_v1beta1.CloudRedisClient()
+                client = redis_v1beta1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1beta1.RescheduleMaintenanceRequest(
@@ -1451,7 +1496,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1534,7 +1579,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1556,7 +1606,9 @@ class CloudRedisAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-redis",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-redis",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
